🔖 [Table of Contents](../../README.md) / [Technical Documentation](../README.md)

# Task Input

- [Input](input.md)
- [BoolInput](bool-input.md)
- [ChoiceInput](choice-input.md)
- [FloatInput](float-input.md)
- [IntInput](int-input.md)
- [PasswordInput](password-input.md)
- [StrInput](str-input.md)

🔖 [Table of Contents](../../README.md) / [Technical Documentation](../README.md)

